@@ -1,4 +1,6 @@
-from typing import Optional, Sequence
+from typing import Optional
+from typing import Sequence
+
 import numpy
 from numpy.typing import ArrayLike
 
