@@ -1,20 +1,22 @@
 """Tools to visualize spectra"""
 
-from est.core.types import XASObject, Spectrum
-from est.core.utils.symbol import MU_CHAR
-from silx.gui import qt
-from silx.gui.plot import Plot1D
-from silx.gui.plot.StackView import StackViewMainWindow
-from silx.utils.enum import Enum
-from silx.gui.widgets.FrameBrowser import HorizontalSliderWithBrowser
-from est.gui import icons
-from silx.gui import icons as silx_icons
-from silx.gui.colors import Colormap
+import logging
 from typing import Iterable
-from ewokscore.missing_data import is_missing_data
+
 import numpy
 import silx
-import logging
+from silx.gui import icons as silx_icons
+from silx.gui import qt
+from silx.gui.colors import Colormap
+from silx.gui.plot import Plot1D
+from silx.gui.plot.StackView import StackViewMainWindow
+from silx.gui.widgets.FrameBrowser import HorizontalSliderWithBrowser
+from silx.utils.enum import Enum
+
+from est.core.types import Spectrum
+from est.core.types import XASObject
+from est.core.utils.symbol import MU_CHAR
+from est.gui import icons
 
 _logger = logging.getLogger(__name__)
 
@@ -168,7 +170,7 @@ class MapViewer(qt.QWidget):
         self._mainWindow = StackViewMainWindow(parent=parent)
         self.layout().addWidget(self._mainWindow)
         self.layout().setContentsMargins(0, 0, 0, 0)
-        self.layout().setSpacing(0.0)
+        self.layout().setSpacing(0)
 
         self._mainWindow.setKeepDataAspectRatio(True)
         self._mainWindow.setColormap(Colormap(name="temperature"))
@@ -184,7 +186,7 @@ class MapViewer(qt.QWidget):
         self.keySelectionDocker = qt.QDockWidget(parent=self)
         self.keySelectionDocker.setContentsMargins(0, 0, 0, 0)
         self._keyWidget.layout().setContentsMargins(0, 0, 0, 0)
-        self._keyWidget.layout().setSpacing(0.0)
+        self._keyWidget.layout().setSpacing(0)
         self.keySelectionDocker.setWidget(self._keyWidget)
         # self._mainWindow.addDockWidget(qt.Qt.TopDockWidgetArea, dockWidget)
         self.keySelectionDocker.setAllowedAreas(qt.Qt.TopDockWidgetArea)
@@ -212,10 +214,11 @@ class MapViewer(qt.QWidget):
         if self._xasObj is None:
             return
         # set the map view
-        spectra_volume = self._xasObj.spectra.map_to(
-            data_info=self.getActiveKey(),
-        )
-        self._mainWindow.setStack(spectra_volume)
+        spectra_volume = self._xasObj.spectra.as_ndarray(self.getActiveKey())
+        if spectra_volume.size:
+            self._mainWindow.setStack(spectra_volume)
+        else:
+            self._mainWindow.clear()
 
     def getPlot(self):
         return self._mainWindow.getPlotWidget()
@@ -311,7 +314,6 @@ class _RawDataList(qt.QTableWidget):
 
 
 class SpectrumViewer(qt.QMainWindow):
-
     sigSpectrumChanged = qt.Signal()
     """Signal emitted when the spectrum change"""
 
@@ -370,11 +372,10 @@ class SpectrumViewer(qt.QMainWindow):
         self._curveOperations.clear()
 
     def setXasObject(self, xas_obj):
-        if xas_obj is None or is_missing_data(xas_obj):
-            self.xas_obj = None
+        self.xas_obj = xas_obj
+        if self.xas_obj is None:
             self.clear()
         else:
-            self.xas_obj = xas_obj
             assert self.xas_obj.spectra.shape[0] >= 0
             assert self.xas_obj.spectra.shape[1] >= 0
             self._dim1FrameBrowser.setRange(0, self.xas_obj.spectra.shape[0] - 1)
@@ -437,7 +438,9 @@ class SpectrumViewer(qt.QMainWindow):
                             kwargs["baseline"] = (res.baseline,)
 
                         curve = self._plotWidget.addCurve(**kwargs)
-                        curve = self._plotWidget.getCurve(curve)
+                        if isinstance(curve, str):
+                            # silx < 2.0
+                            curve = self._plotWidget.getCurve(curve)
                         curve.setAlpha(res.alpha)
                     elif isinstance(res, _XMarkerOperation):
                         if res.x is None or res.x is numpy.nan:
@@ -496,7 +499,7 @@ def _plot_norm(obj, **kwargs):
     if isinstance(obj, XASObject):
         assert "index" in kwargs
         index_dim1 = kwargs["index"]
-        spectra = obj.spectra.map_to("normalized_mu", relative_to="normalized_energy")
+        spectra = obj.spectra.as_ndarray("normalized_mu")
         spectra = spectra[:, index_dim1, :]
         mean = numpy.mean(spectra, axis=1)
         std = numpy.std(spectra, axis=1)
@@ -610,7 +613,7 @@ def _plot_raw(obj, **kwargs):
     elif isinstance(obj, XASObject):
         assert "index" in kwargs
         index_dim1 = kwargs["index"]
-        spectra = obj.spectra.map_to("normalized_mu", relative_to="normalized_energy")
+        spectra = obj.spectra.as_ndarray("normalized_mu")
         spectra = spectra[:, index_dim1, :]
         mean = numpy.mean(spectra, axis=1)
         std = numpy.std(spectra, axis=1)
@@ -713,7 +716,7 @@ def _plot_chi_weighted_k(obj, **kwargs):
     return (_CurveOperation(x=obj.k, y=obj.chi_weighted_k, legend="chi(k) * k_weight"),)
 
 
-def _plot_spectrum(obj, **kwargs):
+def plot_spectrum(obj, **kwargs):
     if not isinstance(obj, Spectrum):
         return None
     energy = _get_energy_for(obj, obj.mu)
@@ -861,15 +864,16 @@ def _normalized_exafs(obj, **kwargs):
 def _ft_window_plot(obj, **kwargs):
     if not isinstance(obj, Spectrum):
         return None
-    missing_keys = obj.ft.get_missing_keys(("K", "WindowWeight"))
-    if len(missing_keys) > 0:
-        _logger.error(f"missing keys {missing_keys} unable to compute normalized EXAFS")
-        return None
-
+    if obj.ft.k is None:
+        _logger.error("missing key 'K': unable to compute normalized EXAFS")
+        return
+    if obj.ft.window_weight is None:
+        _logger.error("missing key 'WindowWeight': unable to compute normalized EXAFS")
+        return
     return (
         _CurveOperation(
-            x=obj.ft["K"],
-            y=obj.ft["WindowWeight"],
+            x=obj.ft.k,
+            y=obj.ft.window_weight,
             legend="FT Window",
             yaxis="right",
             color="red",
@@ -880,28 +884,30 @@ def _ft_window_plot(obj, **kwargs):
 def _ft_intensity_plot(obj, **kwargs):
     if not isinstance(obj, Spectrum):
         return None
-    missing_keys = obj.ft.get_missing_keys(("FTRadius", "FTIntensity"))
-    if len(missing_keys) > 0:
-        _logger.error("missing keys:", missing_keys, "unable to compute spectrum plot")
+    if obj.ft.radius is None:
+        _logger.error("missing key 'FTRadius': unable to compute intensity plot")
+        return
+    if obj.ft.intensity is None:
+        _logger.error("missing key 'FTIntensity': unable to compute intensity plot")
         return
     return (
-        _CurveOperation(
-            x=obj.ft["FTRadius"], y=obj.ft["FTIntensity"], legend="FT Intensity"
-        ),
+        _CurveOperation(x=obj.ft.radius, y=obj.ft.intensity, legend="FT Intensity"),
     )
 
 
 def _ft_imaginary_plot(obj, **kwargs):
     if not isinstance(obj, Spectrum):
         return None
-    missing_keys = obj.ft.get_missing_keys(("FTRadius", "FTImaginary"))
-    if len(missing_keys) > 0:
-        _logger.error("missing keys:", missing_keys, "unable to compute spectrum plot")
+    if obj.ft.radius is None:
+        _logger.error("missing key 'FTRadius': unable to compute imaginary plot")
+        return
+    if obj.ft.intensity is None:
+        _logger.error("missing key 'FTIntensity': unable to compute imaginary plot")
         return
     return (
         _CurveOperation(
-            x=obj.ft["FTRadius"],
-            y=obj.ft["FTImaginary"],
+            x=obj.ft.radius,
+            y=obj.ft.imaginary,
             legend="FT Imaginary",
             color="red",
         ),
