@@ -2,8 +2,12 @@
 This module is used to manage the rsync between files for transfert.
 """
 
+from AnyQt.QtCore import QEvent
+from AnyQt.QtCore import Qt
+from AnyQt.QtCore import QUrl
+from AnyQt.QtCore import pyqtSignal as Signal
 from AnyQt.QtWidgets import QApplication
-from AnyQt.QtCore import Qt, QUrl, QEvent, pyqtSignal as Signal
+
 from est.core.utils.designpattern import singleton
 
 # TODO: this should be removed
