@@ -1,45 +1,31 @@
 import logging
 from datetime import datetime
 from typing import Optional
+from typing import Union
 
 import numpy
-
-from silx.io.dictdump import dicttoh5, dicttonx
+from silx.io.dictdump import dicttoh5
+from silx.io.dictdump import dicttonx
+from silx.io.h5py_utils import File as HDF5File
 from silx.io.url import DataUrl
 from silx.utils.enum import Enum
-from silx.io.h5py_utils import File as HDF5File
 
-from est.io.utils.url import split_spec_url_elmts
-from est.units import ur
+from est import settings
 from est.core.types import Spectra
 from est.core.types import dimensions as dimensions_mod
-from est.io.utils.spec import read_spectrum as read_spec_spectrum
-from est.io.utils import get_data
+from est.io.information import InputInformation
+from est.io.utils import get_ascii_data
+from est.io.utils import get_data_from_url
 from est.io.utils import get_est_data
-from est import settings
-
-
-try:
-    from est.io.utils.larch import read_ascii as larch_read_ascii
-except ImportError:
-    larch_read_ascii = None
+from est.io.utils.ascii import split_ascii_url
+from est.units import ur
 
 _logger = logging.getLogger(__name__)
 
 
 class InputType(Enum):
-    dat_spectrum = "*.dat"  # contains one spectrum
-    hdf5_spectra = "*.h5"  # contains several spectra
-    xmu_spectrum = "*.xmu"  # contains one spectrum
-    csv_spectrum = "*.csv"  # two columns, comma separated
-
-
-def move_axes_to_standard(spectra, dimensions: dimensions_mod.DimensionsType):
-    if isinstance(spectra, Spectra):
-        spectra.data = dimensions_mod.transform_to_standard(spectra.data, dimensions)
-    elif isinstance(spectra, numpy.ndarray):
-        spectra = dimensions_mod.transform_to_standard(spectra, dimensions)
-    return spectra
+    ascii_spectrum = "ascii"  # single or multi scan, single spectrum
+    hdf5_spectra = "hdf5"  # multi scan, multi spectra
 
 
 def load_data(
@@ -49,9 +35,9 @@ def load_data(
     columns_names: Optional[dict] = None,
     energy_unit=ur.eV,
     timeout=settings.DEFAULT_READ_TIMEOUT,
-):
+) -> Union[None, dict, numpy.ndarray, Spectra]:
     """
-    Load a specific data from an url. Manage the different scheme (silx, fabio,
+    Load a specific data from a url. Manage the different scheme (silx, fabio,
     numpy, PyMca, xraylarch)
 
     :param data_url: silx DataUrl with path to the data
@@ -66,71 +52,52 @@ def load_data(
     """
     if data_url is None:
         return None
-
     assert isinstance(data_url, DataUrl)
-    if data_url.scheme() in ("PyMca", "PyMca5", "Spec", "spec", "pymca"):
+    scheme = data_url.scheme().lower()
 
-        def get_scan_title():
-            return split_spec_url_elmts(data_url)["scan_title"]
-
-        energy, mu = read_spec_spectrum(
-            data_url.file_path(),
-            energy_col_name=columns_names["energy"] if columns_names else None,
-            absorption_col_name=columns_names["mu"] if columns_names else None,
-            monitor_col_name=columns_names["monitor"] if columns_names else None,
-            scan_header_S=get_scan_title(),
-            energy_unit=energy_unit,
+    if scheme in ("ascii", "spec", "pymca", "pymca5", "larch", "xraylarch"):
+        return get_ascii_data(
+            data_url, name, columns_names=columns_names, energy_unit=energy_unit
         )
-        if name == "spectra":
-            return mu.reshape(-1, 1, 1)
-        else:
-            return energy
-    elif data_url.scheme() in ("larch", "xraylarch"):
-        if larch_read_ascii is None:
-            _logger.warning("Requires larch to load data from " "%s" % data_url.path())
-            return None
-        else:
-            assert name in ("spectra", "energy")
-            energy, mu = larch_read_ascii(
-                xmu_file=data_url.file_path(), energy_unit=energy_unit
-            )
 
-            if name == "spectra":
-                mu = numpy.ascontiguousarray(mu[:])
-                return mu.reshape(mu.shape[0], 1, 1)
-            else:
-                return energy
-    elif data_url.scheme() == "numpy":
-        return move_axes_to_standard(numpy.load(data_url.file_path()), dimensions)
-    elif data_url.scheme() == "est":
+    if scheme == "numpy":
+        return _move_axes_to_standard(numpy.load(data_url.file_path()), dimensions)
+
+    if scheme == "est":
         assert name == "spectra"
         spectra = get_est_data(data_url, retry_timeout=timeout)
         return Spectra(energy=spectra[0].energy, spectra=spectra)
-    else:
-        if data_url.is_valid():
-            try:
-                data = get_data(data_url, retry_timeout=timeout)
-            except ValueError as e:
-                _logger.error(e)
-            else:
-                if name == "spectra":
-                    if data.ndim == 1:
-                        return data.reshape(data.shape[0], 1, 1)
-                    elif data.ndim == 3:
-                        return move_axes_to_standard(data, dimensions=dimensions)
-                return data
-        else:
-            _logger.warning(
-                "invalid url for {}: {}  will not load it".format(name, data_url)
-            )
+
+    if not data_url.is_valid():
+        _logger.warning("invalid url for %s: %s", name, data_url)
+        return
+
+    try:
+        data = get_data_from_url(data_url, retry_timeout=timeout)
+    except ValueError as e:
+        _logger.error(e)
+        return
+    if name == "spectra":
+        if data.ndim == 1:
+            return data.reshape(data.shape[0], 1, 1)
+        elif data.ndim == 3:
+            return _move_axes_to_standard(data, dimensions=dimensions)
+    return data
 
 
-def read_xas(information, timeout=settings.DEFAULT_READ_TIMEOUT):
+def _move_axes_to_standard(spectra, dimensions: dimensions_mod.DimensionsType):
+    if isinstance(spectra, Spectra):
+        spectra.data = dimensions_mod.transform_to_standard(spectra.data, dimensions)
+    elif isinstance(spectra, numpy.ndarray):
+        spectra = dimensions_mod.transform_to_standard(spectra, dimensions)
+    return spectra
+
+
+def read_xas(information: InputInformation, timeout=settings.DEFAULT_READ_TIMEOUT):
     """
     Read the given spectra, configuration... from the provided input
     Information
 
-    :param InputInformation informationUnion:
 
     :return: spectra, energy, configuration
     """
@@ -149,7 +116,7 @@ def read_xas(information, timeout=settings.DEFAULT_READ_TIMEOUT):
         ["mu", "energy", "monitor"],
     ):
         if url is not None:
-            columns_names[col_name] = split_spec_url_elmts(url)["col_name"]
+            columns_names[col_name] = split_ascii_url(url)["col_name"]
         else:
             columns_names[col_name] = None
 
@@ -199,6 +166,18 @@ def read_xas(information, timeout=settings.DEFAULT_READ_TIMEOUT):
         else:
             energy = energy[: spectra.shape[0]]
 
+    not_strictly_increasing = numpy.diff(energy) <= 0
+    if not_strictly_increasing.any():
+        _logger.warning("Energy is not strictly increasing: sort data by energy")
+        idx = numpy.argsort(energy)
+        energy = energy[idx]
+        spectra = spectra[idx]
+        has_duplicates = numpy.diff(energy) == 0
+        if has_duplicates.any():
+            _logger.warning("Energy has duplicate values: remove duplicates")
+            energy, idx = numpy.unique(energy, return_index=True)
+            spectra = spectra[idx]
+
     return spectra, energy * information.energy_unit, configuration
 
 
@@ -488,8 +467,9 @@ def get_xasproc(h5_file, entry):
 
 if __name__ == "__main__":
     import os
-    from est.core.process.pymca.normalization import PyMca_normalization
+
     from est.core.process.pymca.exafs import PyMca_exafs
+    from est.core.process.pymca.normalization import PyMca_normalization
     from est.core.types import Sample
 
     h5_file = "test_xas_123.h5"
