@@ -1,31 +1,32 @@
-from typing import Union, Tuple
+from typing import Tuple
+
 import numpy
 from numpy.typing import ArrayLike
+
 from est.resources import resource_path
 
 
-def example_spectrum(
-    spectrum: Union[Tuple, str] = "exafs/EXAFS_Ge.dat"
-) -> Tuple[ArrayLike, ArrayLike]:
-    if isinstance(spectrum, tuple):
-        energy = numpy.linspace(*spectrum)  # eV
+def example_spectrum(*args) -> Tuple[ArrayLike, ArrayLike]:
+    if not args:
+        args = "exafs", "EXAFS_Ge.dat"
+    if isinstance(args[0], str):
+        with resource_path(*args) as path:
+            energy, mu, *_ = numpy.loadtxt(path).T
+    else:
+        energy = numpy.linspace(*args)  # eV
         mi, ma = energy.min(), energy.max()
         edge = mi + (ma - mi) * 0.08
         mu = numpy.linspace(0.6, 0.1, energy.size) + (energy > edge).astype(int)
-    elif spectrum in ("exafs/EXAFS_Cu.dat", "exafs/EXAFS_Ge.dat", "exafs/cu_rt01.xmu"):
-        energy, mu, *_ = numpy.loadtxt(resource_path(spectrum)).T
-    else:
-        energy, mu = example_spectrum((5000, 5500, 100))
     return energy, mu
 
 
 def example_spectra(
-    spectrum: Union[Tuple, str] = "exafs/EXAFS_Ge.dat",
+    *args,
     shape: Tuple[int] = (0, 1, 1),
     noise: bool = False,
 ) -> Tuple[ArrayLike, ArrayLike]:
     """Replicate a single spectrum to a nD dataset with optional noise addition."""
-    energy, mu = example_spectrum(spectrum=spectrum)
+    energy, mu = example_spectrum(*args)
     nenergy = shape[0]
     if shape[0]:
         assert nenergy <= len(energy)
