@@ -1,7 +1,8 @@
 import h5py
 import numpy
 from silx.io.url import DataUrl
-from est.core.io import read as read_xas
+
+from est.core.io import read_from_url
 from est.core.process.roi import xas_roi
 from est.tests.data import example_spectra
 
@@ -16,13 +17,13 @@ def test_roi(tmpdir):
         f[spectra_path] = spectra
         f[channel_path] = energy
 
-    xas_obj = read_xas(
+    xas_obj = read_from_url(
         spectra_url=DataUrl(file_path=filename, data_path=spectra_path, scheme="silx"),
         channel_url=DataUrl(file_path=filename, data_path=channel_path, scheme="silx"),
         dimensions=(2, 1, 0),
     )
 
-    original_spectra = xas_obj.spectra.map_to(data_info="mu").copy()
+    original_spectra = xas_obj.spectra.as_ndarray("mu").copy()
     assert original_spectra.shape == (16, 100, 30)
     res_xas_obj = xas_roi(
         xas_obj,
@@ -30,6 +31,6 @@ def test_roi(tmpdir):
         roi_size=(10, 20),
     )
     assert res_xas_obj.n_spectrum == 20 * 10
-    reduces_spectra = res_xas_obj.spectra.map_to(data_info="mu").copy()
+    reduces_spectra = res_xas_obj.spectra.as_ndarray("mu").copy()
     assert reduces_spectra.shape == (16, 20, 10)
     numpy.testing.assert_array_equal(original_spectra[:, 50:70, 20:30], reduces_spectra)
