@@ -1,7 +1,7 @@
 """Test the spectrum class"""
 
-from est.tests.data import example_spectra
 from est.core.types import XASObject
+from est.tests.data import example_spectra
 
 
 def test_from_dat(spectrum_cu_from_pymca):
@@ -17,6 +17,5 @@ def test_from_mock():
     spectra = xas_obj.spectra
     assert xas_obj.n_spectrum == 20 * 10
     assert xas_obj.n_spectrum == 20 * 10
-    spectra.keys()
     assert spectra.data.flat[0] == spectra[0, 0]
-    spectra.map_to("mu")
+    spectra.as_ndarray("mu")
