@@ -1,7 +1,6 @@
-from ewokscore.missing_data import is_missing_data
-from orangecontrib.est.widgets.utils.energyroi import EnergyRoiOW
 from est.core.types.xasobject import XASObject
-from .utils import wait_task_executed
+from est.tests.widgets.utils import wait_task_executed
+from orangecontrib.est.widgets.utils.energyroi import EnergyRoiOW
 
 
 def test_energy_roi_widget_behavior(qtapp, spectrum_cu_from_pymca):
@@ -27,14 +26,15 @@ def test_energy_roi_widget_behavior(qtapp, spectrum_cu_from_pymca):
     while qtapp.hasPendingEvents():
         qtapp.processEvents()
     # insure xas_obj is not propagated and the widget is set up
-    assert is_missing_data(widget.get_task_output_value("xas_obj"))
+    xas_obj = widget.get_task_output_value("xas_obj", default=None)
+    assert xas_obj is None
     assert widget._widget.getXasObject() is not None
     assert widget._widget.getROI() == new_energy_roi
 
     # check behavior once validated
     widget.validate()
     wait_task_executed(qtapp, widget)
-    xas_obj = widget.get_task_output_value("xas_obj")
-    assert not is_missing_data(xas_obj)
+    xas_obj = widget.get_task_output_value("xas_obj", default=None)
+    assert xas_obj is not None
     assert xas_obj.energy.min() >= new_energy_roi[0]
     assert xas_obj.energy.max() <= new_energy_roi[1]
