@@ -1,5 +1,5 @@
 import numpy
-from ewokscore.missing_data import is_missing_data
+
 from est.core.types.xasobject import XASObject
 from est.tests.widgets.utils import wait_task_executed
 from orangecontrib.est.widgets.utils.roi import RoiSelectionOW
@@ -36,6 +36,6 @@ def test_roi_selection_widget(qtapp, spectrum_cu_from_pymca):
 
     widget.validate()
     wait_task_executed(qtapp, widget)
-    xas_obj = widget.get_task_output_value("xas_obj")
-    assert not is_missing_data(xas_obj)
+    xas_obj = widget.get_task_output_value("xas_obj", default=None)
+    assert xas_obj is not None
     assert xas_obj.n_spectrum == roi_size[0] * roi_size[1]
