@@ -1,7 +1,8 @@
 import logging
-from ewoksorange.bindings.owwidgets import OWEwoksWidgetOneThread
+
 from ewoksorange.bindings import ow_build_opts
-from ewokscore.missing_data import is_missing_data
+from ewoksorange.bindings.owwidgets import OWEwoksWidgetOneThread
+
 from est.core.types import XASObject
 
 _logger = logging.getLogger(__file__)
@@ -18,12 +19,14 @@ class EstProcessWidget(OWEwoksWidgetOneThread, **ow_build_opts):
         pass
 
     def task_output_changed(self):
-        xas_obj = self.get_task_output_value("xas_obj")
-        if is_missing_data(xas_obj):
+        xas_obj = self.get_task_output_value("xas_obj", default=None)
+        if xas_obj is None:
             _logger.warning("no output data set. Unable to update the GUI")
             return
-        elif isinstance(xas_obj, dict):
+        if isinstance(xas_obj, dict):
             xas_obj = XASObject.from_dict(xas_obj)
+        if not isinstance(xas_obj, XASObject):
+            raise TypeError(str(type(xas_obj)))
 
         if hasattr(self, "_window") and hasattr(self._window, "setXASObj"):
             self._window.setXASObj(xas_obj=xas_obj)
