@@ -22,15 +22,15 @@ WIDGET_HELP_PATH = (
     # Correct DATA_FILES entry is needed in setup.py and documentation has to be built
     # # before the wheel is created.
     ("{}/help/est/index.html".format(sysconfig.get_path("data")), None),
-    ("http://www.silx.org/pub/doc/est/.htmlhelp/latest/", ""),
+    ("https://ewoksest.readthedocs.io/en/latest/user_guide/widgets/index.html", ""),
 )
 
 
 # Entry point for main Orange categories/widgets discovery
 def widget_discovery(discovery):
-    import pkg_resources
+    from ewoksorange.pkg_meta import get_distribution
 
-    dist = pkg_resources.get_distribution("est")
+    dist = get_distribution("est")
     pkgs = [
         "orangecontrib.est.widgets.pymca",
         "orangecontrib.est.widgets.larch",
