@@ -1,8 +1,10 @@
-from ewoksorange.gui.orange_imports import Input, Output
+from ewoksorange.bindings.owwidgets import OWWidget
+from ewoksorange.gui.orange_imports import Input
+from ewoksorange.gui.orange_imports import Output
+from Orange.data import Table
+
 from est.core.types import XASObject
 from est.core.utils.converter import Converter
-from Orange.data import Table
-from ewoksorange.bindings.owwidgets import OWWidget
 
 
 class ConverterOW(OWWidget):
